Method: Oaf::HTTPHandler#method_missing

Defined in:
lib/oaf/httphandler.rb

#method_missing(method, *opt) ⇒ Object

A magic method to handle any and all do_* methods. This allows Oaf to claim some degree of support for any HTTP method, be it a known and commonly used method such as PUT or DELETE, or custom methods.

Parameters:

method

The name of the method being called

*opt

A list of arguments to pass along to the processing method



78
79
80
# File 'lib/oaf/httphandler.rb', line 78

def method_missing method, *opt
  method.to_s =~ /^do_[A-Z]+$/ ? process_request(*opt) : super
end